# General information

This data package provides all data and figures presented in the
manuscript:

- **Manuscript title** A functionalized pyrrole coating to improve fiber-matrix adhesion in carbon polyphenylene sulfide composites

- **Authors** Van Swaaij, Helthuis, Vos, Akkerman & Grouve

- **Affiliation** Department of Mechanics of Solids, Surfaces and Systems, Faculty of Engineering Technology, University of Twente, Enschede, the
Netherlands

- **Contact information** Wouter Grouve (Email: w.j.b.grouve@utwente.nl, ORCID:
0000-0001-5513-9083)

The manuscript is submitted for publication in Polymer Composites in
December 2024. This repository includes:

-   H-NMR and LCMS data related to the synthesis of a pyrrole-based
    coating aimed at enhancing fiber-matrix adhesion in C/PPS composite
    laminates.
-   Mechanical test data (short beam strength and in-plane shear)
    comparing laminates with and without the coating.
-   Post-fracture microscopy images.
-   Python scripts for data processing and figure generation.

# Dataset

The data is organized into the following folders:

- `nmr`: Proton magnetic resonance spectroscopy results for synthesized
    derivatives.
- `lcms`: Liquid chromatography-mass spectrometry data to analyze interactions
    with DPS.
- `ips`: In-plane shear test results on C/PPS laminates.
- `sbs`: Short beam strength test results on C/PPS laminates.
- `microscopy`: Scanning electron microscopy (SEM) images of IPS fracture surfaces.

All numeric data is provides in comma-separated (`.csv`) files, while
the microscopy pictures are provided as `.jpg` images.

## H-NMR data

The `nmr` folder contains proton magnetic resonance spectroscopy
results for two synthesized coatings:

-   2,5-dimethyl-1-phenyl-1H-pyrrole
-   4-(2,5 dimethyl-1H-pyrrole-lyl) benzenethiol

Data is provided as a report (`.pdf`) and a `.csv` file, with
resonance peaks listed. The `.csv` file includes the first frequency axis
(F1) in the first column and intensity in the second.

## LCMS data

The `lcms` folder contains the UV traces of the ultra-high-presure
liquid chromatography (HPLC) analysis for the following samples:

- Reference or blanco measurement
- Diphenyl sulfide (DPS) 5 ppm
- DPS & PyPh
- DPS & PyPh-SH

The data is presented in a `.csv` file with time [s] in the first
column and intensity in the second column.

In addition, the mass spectra (MS) for the pre-cursor and the fragmented
pre-cursor are provided in `.csv` files with the mass to charge ratio
(m/z) in the first column and the intensity in the second.

## IPS data

The `ips` folder contains the in-plane shear test data. The measured
specimen response is presented in `.csv` files with the following
naming convention:

`IPS--[sample]\_[number].csv`

with [sample] being `reference`, `acetone`, `PyPh` or
`PyPh-SH`, while number ranges from 00 to 07 and corresponds to the
specimen number. Each `.csv` file contains the measured nominal strain
[%] in the first column and the nominal stress [MPa] in the second.

The file `IPS--summary.csv` summarizes the data and contains the
following columns:

- `sample` and `specimen`: sample name and specimen number
- `thickness [mm]` and `width [mm]`: specimen dimensions prior
    testing
- `max. force [N]`, `max. displacement [mm]`, `stress [MPa]`: results
- `b1 [mm]` ... `b6 [mm]`: specimen width after testing at six locations
- `eps1 [%]` ... `eps6 [%]`: transverse strain after testing
- `gamma1 [deg]` ... `gamma6 [deg]`: shear angle after testing

Note: Data for the `reference 01` is unavailable due to test
slippage in the clamps.

Note: The widths (`b1 [mm]` ... `b6 [mm]`)of specimens
`reference 05`, `PyPh-SH 04`, `PyPh 07` and `acetone 04` were
not measured as these specimens were used for SEM inspection and cut in
pieces before the width measurements were performed.

## SBS data

The folder `sbs` contains the short beam strength test data. The
measured specimen response is presented in `.csv` files with the
following naming convention:

`SBS--[sample]\_[number].csv`

with [sample] being `reference`, `acetone`, or `PyPh-SH`, while
number ranges from 00 to 14 and corresponds to the specimen number. Each
`.csv` file contains columns with the time [s], the displacement
[mm], the force [N] and the shear stress [MPa].

The file `SBS--summary.csv` summarizes the data and contains the
following columns:

- `sample` and `specimen`: sample name and specimen number
- `thickness [mm]` and `width [mm]`: specimen dimensions prior
  testing
- `force [N]`, `displacement [mm]`, `shear stress [MPa]`: results

Note: The data for `acetone` specimen number `01` and `02` is lacking
because the test failed due to problems with specimen alignment.

## Microscopy

The scanning electron microscopy images (`.jpg`) presented in the
paper are stored in the folder `microscopy`.

# Scripts and figures

Python (v3.10.11) was used to analyze the data and to generate the
graphs, making use of the following packages: matplotlib (v3.5.2), numpy
(v1.25.2) pandas (v2.1.0), SciencePlots (v2.1.0). The used python
scripts are provided in the folder `python`. In addition, a
`requirements.txt` file is provided to help install the required
packages:

>> python -m pip install -r requirements.txt

The folder `figures` contains the figures presented the paper in
`.png` format.
